==> zio-aws-applicationinsights_2.12-5.17.115.1-sources.jar: zio/aws/applicationinsights/model/DescribeProblemObservationsRequest.scala <==
package zio.aws.applicationinsights.model
import zio.ZIO
import zio.aws.applicationinsights.model.primitives.ProblemId
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeProblemObservationsRequest(problemId: ProblemId) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest = {
    import DescribeProblemObservationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
      .builder()
      .problemId(ProblemId.unwrap(problemId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationinsights.model.DescribeProblemObservationsRequest.ReadOnly =
    zio.aws.applicationinsights.model.DescribeProblemObservationsRequest
      .wrap(buildAwsValue())
}
object DescribeProblemObservationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.applicationinsights.model.DescribeProblemObservationsRequest =
      zio.aws.applicationinsights.model
        .DescribeProblemObservationsRequest(problemId)
    def problemId: ProblemId
    def getProblemId: ZIO[Any, Nothing, ProblemId] = ZIO.succeed(problemId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
  ) extends zio.aws.applicationinsights.model.DescribeProblemObservationsRequest.ReadOnly {
    override val problemId: ProblemId =
      zio.aws.applicationinsights.model.primitives.ProblemId(impl.problemId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
  ): zio.aws.applicationinsights.model.DescribeProblemObservationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-applicationinsights_2.12-7.21.15.10-sources.jar: zio/aws/applicationinsights/model/DescribeProblemObservationsRequest.scala <==
package zio.aws.applicationinsights.model
import zio.ZIO
import zio.aws.applicationinsights.model.primitives.{AccountId, ProblemId}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeProblemObservationsRequest(
    problemId: ProblemId,
    accountId: Optional[AccountId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest = {
    import DescribeProblemObservationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
      .builder()
      .problemId(ProblemId.unwrap(problemId): java.lang.String)
      .optionallyWith(
        accountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.accountId)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationinsights.model.DescribeProblemObservationsRequest.ReadOnly =
    zio.aws.applicationinsights.model.DescribeProblemObservationsRequest
      .wrap(buildAwsValue())
}
object DescribeProblemObservationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.applicationinsights.model.DescribeProblemObservationsRequest =
      zio.aws.applicationinsights.model.DescribeProblemObservationsRequest(
        problemId,
        accountId.map(value => value)
      )
    def problemId: ProblemId
    def accountId: Optional[AccountId]
    def getProblemId: ZIO[Any, Nothing, ProblemId] = ZIO.succeed(problemId)
    def getAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("accountId", accountId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
  ) extends zio.aws.applicationinsights.model.DescribeProblemObservationsRequest.ReadOnly {
    override val problemId: ProblemId =
      zio.aws.applicationinsights.model.primitives.ProblemId(impl.problemId())
    override val accountId: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.accountId())
      .map(value =>
        zio.aws.applicationinsights.model.primitives.AccountId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationinsights.model.DescribeProblemObservationsRequest
  ): zio.aws.applicationinsights.model.DescribeProblemObservationsRequest.ReadOnly =
    new Wrapper(impl)
}
